@@ -20,7 +20,9 @@ class UndevelopedEventItem(Classified, ElementPresentation):
     def __init__(self, diagram, id=None):
         super().__init__(diagram, id, width=WIDE_FTA_WIDTH, height=WIDE_FTA_HEIGHT)
 
-        self.watch("subject.name").watch("subject.namespace.name")
+        self.watch("subject[UML:NamedElement].name").watch(
+            "subject[UML:NamedElement].namespace.name"
+        )
 
     def update_shapes(self, event=None):
         self.shape = IconBox(
